==> ukui-tablet-desktop_4.0.0.0.orig.tar.gz: ukui-tablet-desktop-4.0.0.0/tablet-desktop-backend/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <source>Mobile</source>
        <translation type="unfinished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="unfinished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="unfinished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished">系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="unfinished">安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished">其他</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UKUI::TabletDesktopBackend</name>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
<context>
    <name>UKUI::kylinTabletDesktopBackend</name>
    <message>
        <source>education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
</TS>

==> ukui-tablet-desktop_4.10.0.0.orig.tar.gz: ukui-tablet-desktop-4.10.0.0/tablet-desktop-backend/translations/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <source>Mobile</source>
        <translation>移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation>社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
</context>
<context>
    <name>UKUI::TabletDesktopBackend</name>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Safe</source>
        <translation type="vanished">安全</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
<context>
    <name>UKUI::kylinTabletDesktopBackend</name>
    <message>
        <source>education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="vanished">移动</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络</translation>
    </message>
    <message>
        <source>Social</source>
        <translation type="vanished">社交</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">影音</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">开发</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公</translation>
    </message>
    <message>
        <source>Education</source>
        <translation type="vanished">教育</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他</translation>
    </message>
</context>
</TS>
